==> nextcloud-21.0.4.tgz: nextcloud/apps/federatedfilesharing/l10n/es_PA.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "¿Desea agregar el elemento compartido remoto {name} de {owner}@{remote}?",
    "Remote share" : "Elemento compartido remoto",
    "Remote share password" : "Contraseña del elemento compartido remoto",
    "Cancel" : "Cancelar",
    "Add remote share" : "Agregar elemento compartido remoto",
    "Copy" : "Copiar",
    "Copied!" : "¡Copiado!",
    "Not supported!" : "¡No soportado!",
    "Press ⌘-C to copy." : "Presiona ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Presiona Ctrl-C para copiar.",
    "Invalid Federated Cloud ID" : "El ID es inválido",
    "Server to server sharing is not enabled on this server" : "Compartir de servidor a servidor no está habilitado en este servidor",
    "Couldn't establish a federated share." : "No fue posible establecer el elemento compartido. ",
    "Couldn't establish a federated share, maybe the password was wrong." : "No fue posible establecer el elemento compartido federado, tal vez la contraseña sea incorrecta. ",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Solicitud de elemento compartido Federado enviada, recibiras una invitación. Verifica tus notificaciones.",
    "Not allowed to create a federated share with the same user" : "No está permitido crear un elelmento compartido federado con el mismo usuario",
    "File is already shared with %s" : "El archivo ya ha sido compartido con %s",
    "Could not find share" : "No fue posible encontrar el elemento compartido",
    "Federated sharing" : "Elementos compartidos",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Has recibido {share} como un elemento compartido remoto de {user} (de parte de {behalf})",
    "You received {share} as a remote share from {user}" : "Recibiste {share} como un elemento compartido remoto de {user}",
    "Accept" : "Aceptar",
    "Decline" : "Rechazar",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Compartir conmigo a través de mi ID de Nube Federada #Nextcloud, ver %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Compartir conmigo a través de mi ID de Nube Federada #Nextcloud",
    "Sharing" : "Compartiendo",
    "Federated Cloud Sharing" : "Compartiendo en la Nube Federada",
    "Open documentation" : "Abrir documentación",
    "Allow users on this server to receive shares from other servers" : "Permitirle alos usuarios de este servidor recibir elementos compartidos de otros servidores",
    "Search global and public address book for users" : "Buscar usuarios en las libretas de contactos globales y públicas",
    "Allow users to publish their data to a global and public address book" : "Permitirle a los usuarios publicar sus datos a una libreta de direcciones global y pública",
    "Federated Cloud" : "Nube Federada",
    "Your Federated Cloud ID:" : "Tu ID de Nube Federada:",
    "Share it so your friends can share files with you:" : "Compártelo para que tus amigos puedan compartir archivos contigo:",
    "Add to your website" : "Agregar a tu sitio web",
    "Share with me via Nextcloud" : "Compartir conmigo vía Nextcloud",
    "HTML Code:" : "Código HTML:",
    "Adjust how people can share between servers." : "Ajustar cómo las personas pueden compartir entre servidores. "
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-29.0.5.tgz: nextcloud/apps/federatedfilesharing/l10n/es_PA.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Invalid Federated Cloud ID" : "El ID es inválido",
    "Server to server sharing is not enabled on this server" : "Compartir de servidor a servidor no está habilitado en este servidor",
    "Couldn't establish a federated share." : "No fue posible establecer el elemento compartido. ",
    "Couldn't establish a federated share, maybe the password was wrong." : "No fue posible establecer el elemento compartido federado, tal vez la contraseña sea incorrecta. ",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "Solicitud de elemento compartido Federado enviada, recibiras una invitación. Verifica tus notificaciones.",
    "File is already shared with %s" : "El archivo ya ha sido compartido con %s",
    "Could not find share" : "No fue posible encontrar el elemento compartido",
    "Federated sharing" : "Elementos compartidos",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Has recibido {share} como un elemento compartido remoto de {user} (de parte de {behalf})",
    "You received {share} as a remote share from {user}" : "Recibiste {share} como un elemento compartido remoto de {user}",
    "Accept" : "Aceptar",
    "Decline" : "Rechazar",
    "Federated Cloud Sharing" : "Compartiendo en la Nube Federada",
    "Sharing" : "Compartiendo",
    "Federated Cloud" : "Nube Federada",
    "Your Federated Cloud ID:" : "Tu ID de Nube Federada:",
    "Share it so your friends can share files with you:" : "Compártelo para que tus amigos puedan compartir archivos contigo:",
    "Twitter" : "Twitter",
    "Add to your website" : "Agregar a tu sitio web",
    "Share with me via Nextcloud" : "Compartir conmigo vía Nextcloud",
    "HTML Code:" : "Código HTML:",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Compartir conmigo a través de mi ID de Nube Federada #Nextcloud",
    "Copy to clipboard" : "Copiar al portapapeles",
    "Copied!" : "¡Copiado!",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "¿Desea agregar el elemento compartido remoto {name} de {owner}@{remote}?",
    "Remote share" : "Elemento compartido remoto",
    "Remote share password" : "Contraseña del elemento compartido remoto",
    "Cancel" : "Cancelar",
    "Add remote share" : "Agregar elemento compartido remoto",
    "Not allowed to create a federated share with the same user" : "No está permitido crear un elelmento compartido federado con el mismo usuario",
    "Allow users on this server to receive shares from other servers" : "Permitirle alos usuarios de este servidor recibir elementos compartidos de otros servidores",
    "Search global and public address book for users" : "Buscar usuarios en las libretas de contactos globales y públicas",
    "Allow users to publish their data to a global and public address book" : "Permitirle a los usuarios publicar sus datos a una libreta de direcciones global y pública"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
